@@ -1,6 +1,6 @@
 package Pod::Weaver::Section::Name;
 BEGIN {
-  $Pod::Weaver::Section::Name::VERSION = '3.101460';
+  $Pod::Weaver::Section::Name::VERSION = '3.101632';
 }
 use Moose;
 with 'Pod::Weaver::Role::Section';
@@ -13,25 +13,56 @@ use Pod::Elemental::Element::Pod5::Command;
 use Pod::Elemental::Element::Pod5::Ordinary;
 use Pod::Elemental::Element::Nested;
 
+sub _get_docname_via_statement {
+  my ($self, $ppi_document) = @_;
+
+  my $pkg_node = $ppi_document->find_first('PPI::Statement::Package');
+  return unless $pkg_node;
+  return $pkg_node->namespace;
+}
+
+sub _get_docname_via_comment {
+  my ($self, $ppi_document) = @_;
+
+  my ($docname) = $ppi_document->serialize =~ /^\s*#+\s*PODNAME:\s*(.+)$/m;
+  return $docname;
+}
+
+sub _get_docname {
+  my ($self, $input) = @_;
+
+  my $ppi_document = $input->{ppi_document};
+
+  my $docname = $self->_get_docname_via_comment($ppi_document)
+             || $self->_get_docname_via_statement($ppi_document);
+
+  return $docname;
+}
+
+sub _get_abstract {
+  my ($self, $input) = @_;
+
+  my $ppi_document = $input->{ppi_document};
+
+  my ($abstract) = $ppi_document->serialize =~ /^\s*#+\s*ABSTRACT:\s*(.+)$/m;
+
+  return $abstract;
+}
+
 sub weave_section {
   my ($self, $document, $input) = @_;
 
-  return unless my $ppi_document = $input->{ppi_document};
-  my $pkg_node = $ppi_document->find_first('PPI::Statement::Package');
-
   my $filename = $input->{filename} || 'file';
 
-  Carp::croak sprintf "couldn't find package declaration in %s", $filename
-    unless $pkg_node;
+  my $docname  = $self->_get_docname($input);
+  my $abstract = $self->_get_abstract($input);
 
-  my $package = $pkg_node->namespace;
-
-  my ($abstract)
-    = $ppi_document->serialize =~ /^\s*#+\s*ABSTRACT:\s*(.+)$/m;
+  Carp::croak sprintf "couldn't determine document name for %s", $filename
+    unless $docname;
 
   $self->log([ "couldn't find abstract in %s", $filename ]) unless $abstract;
  
-  my $name = $package;
+  my $name = $docname;
   $name .= " - $abstract" if $abstract;
 
   my $name_para = Pod::Elemental::Element::Nested->new({
@@ -56,7 +87,7 @@ Pod::Weaver::Section::Name - add a NAME section with abstract (for your Perl mod
 
 =head1 VERSION
 
-version 3.101460
+version 3.101632
 
 =head1 OVERVIEW
 
@@ -68,14 +99,17 @@ as well as an abstract, like this:
   Some::Document - a document for some
 
 It will determine the name and abstract by inspecting the C<ppi_document> which
-must be given.  It will look for the first package declaration, and for a
-comment in this form:
+must be given.  It looks for comments in the form:
 
   # ABSTRACT: a document for some
+  # PODNAME: Some::Package::Name
+
+If no C<PODNAME> comment is present, but a package declaration can be found,
+the package name will be used as the document name.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
